@@ -82,7 +82,6 @@ struct Config {
   bool isCLI = false;
   std::string networkFile;
   std::vector<std::string> additionalInput;
-  std::string inputFormat;
   bool stateInput = false;
   bool stateOutput = false;
   bool multilayerInput = false;
@@ -97,7 +96,7 @@ struct Config {
   //bool nonBacktracking = false; // unused
   bool parseWithoutIOStreams = false;
   bool zeroBasedNodeNumbers = false;
-  bool includeSelfLinks = false;
+  bool noSelfLinks = false; // Replaces includeSelfLinks
   bool ignoreEdgeWeights = false;
   unsigned int nodeLimit = 0;
   bool preClusterMultilayer = false;
@@ -134,8 +133,12 @@ struct Config {
   bool noCoarseTune = false;
   bool directedEdges = false; // For clustering
   bool recordedTeleportation = false;
+  bool regularized = false; // Add a Bayesian prior network with recorded teleportation (sets recordedTeleportation and teleportToNodes to true)
+  double regularizationStrength = 1.0; // Scale Bayesian prior constant ln(N)/N with this factor
   double teleportationProbability = 0.15;
   unsigned int preferredNumberOfModules = 0;
+  bool entropyBiasCorrection = false;
+  double entropyBiasCorrectionMultiplier = 1;
   unsigned long seedToRandomNumberGenerator = 123;
 
   // Performance and accuracy
@@ -203,7 +206,6 @@ struct Config {
     isCLI = other.isCLI;
     networkFile = other.networkFile;
     additionalInput = other.additionalInput;
-    inputFormat = other.inputFormat;
     stateInput = other.stateInput;
     stateOutput = other.stateOutput;
     multilayerInput = other.multilayerInput;
@@ -218,7 +220,7 @@ struct Config {
     //nonBacktracking = other.nonBacktracking;
     parseWithoutIOStreams = other.parseWithoutIOStreams;
     zeroBasedNodeNumbers = other.zeroBasedNodeNumbers;
-    includeSelfLinks = other.includeSelfLinks;
+    noSelfLinks = other.noSelfLinks;
     ignoreEdgeWeights = other.ignoreEdgeWeights;
     nodeLimit = other.nodeLimit;
     preClusterMultilayer = other.preClusterMultilayer;
@@ -251,8 +253,12 @@ struct Config {
     noCoarseTune = other.noCoarseTune;
     directedEdges = other.directedEdges;
     recordedTeleportation = other.recordedTeleportation;
+    regularized = other.regularized;
+    regularizationStrength = other.regularizationStrength;
     teleportationProbability = other.teleportationProbability;
     // preferredNumberOfModules = other.preferredNumberOfModules;
+    entropyBiasCorrection = other.entropyBiasCorrection;
+    entropyBiasCorrectionMultiplier = other.entropyBiasCorrectionMultiplier;
     seedToRandomNumberGenerator = other.seedToRandomNumberGenerator;
     // numTrials = other.numTrials;
     minimumCodelengthImprovement = other.minimumCodelengthImprovement;
@@ -369,11 +375,8 @@ struct Config {
 
   bool printAsUndirected() const { return isUndirectedClustering(); }
 
-  bool is3gram() const { return inputFormat == "3gram"; }
-  bool isPath() const { return inputFormat == "path"; }
-  bool isMultilayerNetwork() const { return multilayerInput || inputFormat == "multilayer" || inputFormat == "multiplex" || !additionalInput.empty(); }
-  bool isStateNetwork() const { return inputFormat == "states"; }
-  bool isBipartite() const { return inputFormat == "bipartite" || bipartite; }
+  bool isMultilayerNetwork() const { return multilayerInput || !additionalInput.empty(); }
+  bool isBipartite() const { return bipartite; }
 
   bool haveMemory() const { return stateInput; }
   bool printStates() const { return stateOutput; }
