@@ -23,6 +23,7 @@ Config::Config(std::string flags, bool isCLI) : isCLI(isCLI)
 
   api.setGroups({ "Input", "Algorithm", "Accuracy", "Output" });
 
+  bool deprecated_includeSelfLinks = false;
   std::vector<std::string> optionalOutputDir; // Used if !isCLI
   // --------------------- Input options ---------------------
   if (isCLI) {
@@ -34,15 +35,15 @@ Config::Config(std::string flags, bool isCLI) : isCLI(isCLI)
     api.addOptionArgument(networkFile, "input", "File containing the network data. Assumes a link list format if no Pajek formatted heading.", ArgType::path, "Input");
   }
 
-  api.addOptionArgument(inputFormat, 'i', "input-format", "Override automatically recognized types. Options: pajek, link-list, bipartite, multilayer, states.", ArgType::option, "Input", true);
-
   api.addOptionArgument(skipAdjustBipartiteFlow, "skip-adjust-bipartite-flow", "Skip distributing all flow from the bipartite nodes to the primary nodes.", "Input", true);
 
   api.addOptionArgument(bipartiteTeleportation, "bipartite-teleportation", "Teleport like the bipartite flow instead of two-step (unipartite) teleportation.", "Input", true);
 
   api.addOptionArgument(weightThreshold, "weight-threshold", "Limit the number of links to read from the network. Ignore links with less weight than the threshold.", ArgType::number, "Input", true);
 
-  api.addOptionArgument(includeSelfLinks, 'k', "include-self-links", "Include links with the same source and target node.", "Input", true);
+  api.addOptionArgument(deprecated_includeSelfLinks, 'k', "include-self-links", "DEPRECATED. Include self links by default now, exclude with --no-self-links.", "Input", true);
+
+  api.addOptionArgument(noSelfLinks, "no-self-links", "Exclude self links in the input network.", "Input", true);
 
   api.addOptionArgument(nodeLimit, "node-limit", "Limit the number of nodes to read from the network. Ignore links connected to ignored nodes.", ArgType::integer, "Input", true);
 
@@ -94,8 +95,8 @@ Config::Config(std::string flags, bool isCLI) : isCLI(isCLI)
 
   api.addOptionArgument(directed, 'd', "directed", "Assume directed links. Shorthand for '--flow-model directed'.", "Algorithm");
 
-  // api.addOptionArgument(recordedTeleportation, 'e', "recorded-teleportation",
-  // 		"If teleportation is used to calculate the flow, also record it when minimizing codelength.", "Algorithm", true);
+  api.addOptionArgument(recordedTeleportation, 'e', "recorded-teleportation",
+  		"If teleportation is used to calculate the flow, also record it when minimizing codelength.", "Algorithm", true);
 
   api.addOptionArgument(useNodeWeightsAsFlow, "use-node-weights-as-flow", "Use node weights (from api or after names in Pajek format) as flow, normalized to sum to 1", "Algorithm", true);
 
@@ -103,6 +104,14 @@ Config::Config(std::string flags, bool isCLI) : isCLI(isCLI)
 
   api.addOptionArgument(teleportationProbability, 'p', "teleportation-probability", "Probability of teleporting to a random node or link.", ArgType::probability, "Algorithm", true);
 
+  api.addOptionArgument(regularized, "regularized", "Effectively add a fully connected Bayesian prior network to not overfit due to missing links. Implies recorded teleportation", "Algorithm", true);
+
+  api.addOptionArgument(regularizationStrength, "regularization-strength", "Adjust relative strength of Bayesian prior network with this multiplier.", ArgType::number, "Algorithm", true);
+
+  api.addOptionArgument(entropyBiasCorrection, "entropy-corrected", "Correct for negative entropy bias in small samples (many modules).", "Algorithm", true);
+
+  api.addOptionArgument(entropyBiasCorrectionMultiplier, "entropy-correction-strength", "Increase or decrease the default entropy correction with this factor.", ArgType::number, "Algorithm", true);
+
   // api.addOptionArgument(selfTeleportationProbability, 'y', "self-link-teleportation-probability",
   // 		"Additional probability of teleporting to itself. Effectively increasing the code rate, generating more and smaller modules.", ArgType::number, "Algorithm", true);
 
@@ -185,6 +194,10 @@ Config::Config(std::string flags, bool isCLI) : isCLI(isCLI)
 
   api.parseArgs(flags);
 
+  if (deprecated_includeSelfLinks) {
+    throw InputDomainError("The --include-self-links flag is deprecated to include self links by default. Use --no-loops to exclude.");
+  }
+
   if (!optionalOutputDir.empty())
     outDirectory = optionalOutputDir[0];
 
@@ -207,6 +220,11 @@ Config::Config(std::string flags, bool isCLI) : isCLI(isCLI)
     setFlowModel(FlowModel::rawdir);
   }
 
+  if (regularized) {
+    recordedTeleportation = true;
+    // teleportToNodes = true;
+  }
+
   // Some checks
   if (*--outDirectory.end() != '/')
     outDirectory.append("/");
